@@ -6,7 +6,7 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-scroll-on-jump
-;; Version: 0.2
+;; Version: 0.3
 ;; Package-Requires: ((emacs "26.2"))
 
 ;;; Commentary:
@@ -58,7 +58,7 @@
   :type 'boolean)
 
 (defcustom scroll-on-jump-curve 'smooth
-  "The the method scrolling is calculated."
+  "The method for calculating scrolling speed."
   :type
   '(choice (const :tag "Smooth in/out, starts & ends slow" smooth)
            (const :tag "Smooth in, starts slow" smooth-in)
@@ -66,16 +66,16 @@
            (const :tag "Linear" linear)))
 
 (defcustom scroll-on-jump-curve-power 3.0
-  "The strength of the curve (when set to linear).
+  "The strength of the curve (ignored when set to linear).
 A value of 1.0 is linear, values between 2 and 8 work well."
   :type 'float)
 
 (defcustom scroll-on-jump-mode-line-format nil
   "The `mode-line-format' to use or nil to leave the `mode-line-format' unchanged.
 
-This can be useful to use a simplified or event disabling the mode-line
+This can be useful for simplifying or even disabling the mode-line
 while scrolling, as a complex mode-line can interfere with smooth scrolling."
-  :type '(choice (const nil) string))
+  :type '(choice (const :tag "Unchanged" nil) sexp))
 
 
 ;; ---------------------------------------------------------------------------
@@ -96,12 +96,13 @@ Move LINES in WINDOW, when ALSO-MOVE-POINT is set, the point is moved too."
                     t))
 
 ;; Per-line Scroll.
-;; return remainder of lines to scroll (matching forward-line).
 (defun scroll-on-jump--scroll-by-lines (window lines also-move-point)
-  "Line based scroll that optionally move the point.
+  "Line based scroll that optionally moves the point.
 Argument WINDOW The window to scroll.
 Argument LINES The number of lines to scroll (signed).
-Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
+Argument ALSO-MOVE-POINT When non-nil, move the POINT as well.
+
+Return remainder of lines to scroll (matching `forward-line')."
   (declare (important-return-value t))
   (let ((lines-remainder 0))
     (when also-move-point
@@ -120,15 +121,15 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
           (forward-line (- lines-remainder)))))
     lines-remainder))
 
-
 ;; Per-pixel Scroll,
-;; return remainder of lines to scroll (matching forward-line).
 (defun scroll-on-jump--scroll-by-pixels (window char-height delta-px also-move-point)
-  "Line based scroll that optionally move the point.
+  "Pixel based scroll that optionally moves the point.
 Argument WINDOW The window to scroll.
 Argument CHAR-HEIGHT The result of `frame-char-height'.
 Argument DELTA-PX The number of pixels to scroll (signed).
-Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
+Argument ALSO-MOVE-POINT When non-nil, move the POINT as well.
+
+Return remainder of lines to scroll (matching `forward-line')."
   (declare (important-return-value nil))
   (cond
    ((< delta-px 0)
@@ -181,12 +182,11 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
 
 (defsubst scroll-on-jump--set-mark-from-point ()
   "Convenience function to set the mark to the point."
-  (let ((m (mark-marker)))
-    ;; This should practically never be nil,
-    ;; although it's not impossible the mark is somehow cleared while drawing,
-    ;; in this case, doing nothing is OK.
-    (when m
-      (set-marker m (point)))))
+  ;; This should practically never be nil,
+  ;; although it's not impossible the mark is somehow cleared while drawing,
+  ;; in this case, doing nothing is OK.
+  (when-let* ((m (mark-marker)))
+    (set-marker m (point))))
 
 (defmacro scroll-on-jump--save-mark-conditionally (test-condition &rest body)
   "Run BODY, restoring the marks original location when TEST-CONDITION is non-nil."
@@ -201,16 +201,15 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
                 ,@body)
          ;; Unlikely but possible the mark no longer exists.
          (when ,mk-pos
-           (let ((mk (mark-marker)))
-             (when mk
-               (set-marker mk ,mk-pos))))))))
+           (when-let* ((mk (mark-marker)))
+             (set-marker mk ,mk-pos)))))))
 
 
 ;; ---------------------------------------------------------------------------
 ;; Internal Interpolation Functions
 
 (defsubst scroll-on-jump--interp-linear-impl (a b factor)
-  "Internal macro for to blend A, B by FACTOR."
+  "Blend A toward B by FACTOR."
   (+ a (* (- b a) factor)))
 
 (defun scroll-on-jump--interp-linear (a b factor)
@@ -224,7 +223,7 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
   (scroll-on-jump--interp-linear-impl a b (expt factor scroll-on-jump-curve-power)))
 
 (defun scroll-on-jump--interp-ease-out (a b factor)
-  "Blend FACTOR between A and B using ease-in curvature."
+  "Blend FACTOR between A and B using ease-out curvature."
   (declare (important-return-value t))
   (scroll-on-jump--interp-linear-impl
    a b (- 1.0 (expt (- 1.0 factor) scroll-on-jump-curve-power))))
@@ -264,7 +263,7 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
 ;; ---------------------------------------------------------------------------
 ;; Internal Logic
 
-(defun scroll-on-jump--immediate-scroll (window lines-scroll _dir)
+(defun scroll-on-jump--immediate-scroll (window lines-scroll)
   "Non animated scroll for WINDOW to move LINES-SCROLL."
   (declare (important-return-value nil))
   (scroll-on-jump--scroll-by-lines-simple window lines-scroll nil))
@@ -275,7 +274,7 @@ Moving the point when ALSO-MOVE-POINT is set."
   (declare (important-return-value nil))
   (let ((time-init (current-time))
         ;; For motion less than a window, scale down the time allowed.
-        ;; This means moving a short distance wont be given the full time.
+        ;; This means moving a short distance won't be given the full time.
         (time-limit
          (* scroll-on-jump-duration
             (min 1.0 (/ (float (abs lines-scroll)) (float (window-body-height window))))))
@@ -285,7 +284,7 @@ Moving the point when ALSO-MOVE-POINT is set."
 
     ;; Animated scrolling (early exit on input to avoid annoying lag).
     (cond
-     ((not (zerop lines-scroll))
+     ((null (zerop lines-scroll))
       (let ((is-early-exit t)
             (lines-done-abs 0)
             (lines-scroll-abs (abs lines-scroll))
@@ -330,7 +329,7 @@ Moving the point when ALSO-MOVE-POINT is set."
             (setq is-early-exit nil)))
 
         ;; Re-enable when editing logic.
-        (when (and (null is-early-exit) (not (zerop lines-scroll)))
+        (when (and (null is-early-exit) (null (zerop lines-scroll)))
           (error "Internal error, 'lines-scroll' should be zero"))
 
         ;; If we exit early because of input.
@@ -349,7 +348,7 @@ Argument ALSO-MOVE-POINT moves the point while scrolling."
   (declare (important-return-value nil))
   (let ((time-init (current-time))
         ;; For motion less than a window, scale down the time allowed.
-        ;; This means moving a short distance wont be given the full time.
+        ;; This means moving a short distance won't be given the full time.
         (time-limit
          (* scroll-on-jump-duration
             (min 1.0 (/ (float (abs lines-scroll)) (float (window-body-height window))))))
@@ -361,7 +360,7 @@ Argument ALSO-MOVE-POINT moves the point while scrolling."
 
     ;; Animated scrolling (early exit on input to avoid annoying lag).
     (cond
-     ((not (zerop lines-scroll))
+     ((null (zerop lines-scroll))
       (let ((is-early-exit t)
             (px-done-abs 0)
             (px-scroll-abs (abs (* lines-scroll char-height)))
@@ -427,12 +426,12 @@ Argument ALSO-MOVE-POINT moves the point while scrolling."
             (scroll-on-jump--scroll-by-lines-simple window lines-scroll nil))
 
            ;; Sanity check, if this fails there is an issue with internal logic.
-           ((not (zerop px-scroll))
+           ((null (zerop px-scroll))
             (set-window-vscroll window 0 t)
             (error "Internal error, 'px-scroll' should be zero"))
 
            ;; Also should never happen.
-           ((not (zerop (window-vscroll window t)))
+           ((null (zerop (window-vscroll window t)))
             (set-window-vscroll window 0 t)
             (message "Warning, sub-pixel scroll left set!"))))))
 
@@ -444,7 +443,7 @@ Argument ALSO-MOVE-POINT moves the point while scrolling."
 
 (defun scroll-on-jump--scroll-animated (window lines-scroll dir also-move-point)
   "Perform an animated scroll.
-see `scroll-on-jump--scroll-impl' for doc-strings for WINDOW, LINES-SCROLL, DIR & ALSO-MOVE-POINT."
+See `scroll-on-jump--scroll-impl' for doc-strings for WINDOW, LINES-SCROLL, DIR & ALSO-MOVE-POINT."
   (declare (important-return-value nil))
   (cond
    ;; Use pixel scrolling.
@@ -468,7 +467,7 @@ Moving the point when ALSO-MOVE-POINT is set."
   (cond
    ;; No animation.
    ((zerop scroll-on-jump-duration)
-    (scroll-on-jump--immediate-scroll window lines-scroll dir))
+    (scroll-on-jump--immediate-scroll window lines-scroll))
    ;; Animated scroll.
    (scroll-on-jump-mode-line-format
     (prog1 (let ((mode-line-format scroll-on-jump-mode-line-format))
@@ -528,7 +527,7 @@ Moving the point when ALSO-MOVE-POINT is set."
                          (goto-char (window-start window))
                          (forward-line lines-scroll))))))))
 
-        (let ((also-move-point (not (eq (point) point-next))))
+        (let ((also-move-point (null (eq (point) point-next))))
           (scroll-on-jump--scroll-impl window lines-scroll dir also-move-point)))))
 
   (goto-char point-next))
@@ -574,14 +573,14 @@ Argument USE-WINDOW-START detects window scrolling when non-nil."
              ;; this has the advantage that we could get the resulting cursor location
              ;; even in the case of an error.
              ;; However - this makes troubleshooting problems considerably more difficult.
-             ;; As it wont show the full back-trace, only the error message.
+             ;; As it won't show the full back-trace, only the error message.
              ;; So don't prioritize correct jumping in the case of errors and assume errors
              ;; are not something that happen after cursor motion.
              (scroll-on-jump--outer-scoped-mark point-orig point-prev
                (scroll-on-jump--inner-scoped-mark (window-start window) window-start-prev
                  (scroll-on-jump--inner-scoped-mark point-orig point-next
                    ;; Run the main body of this function.
-                   ;; It's important the result if returned (hence the `prog1' use).
+                   ;; It's important the result is returned (hence the `prog1' use).
                    (funcall body-fn)))))
 
       ;; Quiet unused argument warning.
@@ -589,7 +588,7 @@ Argument USE-WINDOW-START detects window scrolling when non-nil."
 
       (cond
        ;; Context changed or recursed, simply jump.
-       ((not
+       ((null
          ;; Check if the buffer/context changed.
          (and (eq buf (window-buffer window))
               (eq buf (current-buffer))
@@ -617,7 +616,7 @@ Argument USE-WINDOW-START detects window scrolling when non-nil."
                      1)
                     (t
                      -1)))
-                  (also-move-point (not (eq (point) point-next))))
+                  (also-move-point (null (eq (point) point-next))))
               (scroll-on-jump--scroll-impl window (* dir lines-scroll) dir also-move-point)))
           (prog1 (goto-char point-next)
             (redisplay t)))
@@ -643,7 +642,7 @@ Argument USE-WINDOW-START detects window scrolling when non-nil."
 
 ;;;###autoload
 (defun scroll-on-jump-interactive (fn)
-  "Macro that wraps interactive call to function FN.
+  "Function that wraps interactive call to function FN.
 
 Use if you want to use `scroll-on-jump' for a single `key-binding',
 without changing behavior anywhere else."
@@ -684,7 +683,7 @@ This calls (calling OLD-FN with ARGS)."
 
 ;;;###autoload
 (defun scroll-on-jump-with-scroll-interactive (fn)
-  "Macro that wraps interactive call to function FN.
+  "Function that wraps interactive call to function FN.
 
 Use if you want to use `scroll-on-jump-with-scroll' for a single `key-binding',
 without changing behavior anywhere else."
